@@ -32,7 +32,8 @@ sub sql
 {
 	my $self = shift;
 
-	my @rv = $self -> gen_clauses( @_ );
+	my @rv = $self -> gen_clauses( &LittleORM::Model::__for_read(), # default, can be overwritten with following in @_
+				       @_ );
 
 	return sprintf( ' ( %s ) ', join( ' '. $self -> logic() . ' ', @rv ) );
 }
@@ -74,7 +75,7 @@ sub gen_clauses
 
 	unless( @rv )
 	{
-		@rv = ( '1=1' );
+		@rv = ( '2=2' );
 	}
 
 	return @rv;
